:: This script (prototype) helps you playback an AutoDriver recording--usually one you just
:: created with RecordAutoDriverInputs.bat. It uses the same environment variables you
:: setup for the recording to initiate the playback (optionally) on a different device
:: that also has the target app installed. Use this batch file to review your autodriver file
:: before you use it in an E2E test.
::
:: Prerequisites:
:: 1) Run RecordAutoDriverInputs.bat to create a new autodriver file.
:: 2) (optional) plug in a different device to your computer.  Note that the same target App
::  (APK and OBB if applicable) must reside on this device too.
::
:: Instructions:
:: 1) Run the script
:: 2) Put on your headset and watch the recording.
:: 3) If it looks ok, then use the recording to create an E2E test.

@echo off
setlocal enabledelayedexpansion

:: Setup system and device variables.
if "%ADB%"=="" set ADB=adb.exe
%ADB% help > nul
if "%ERRORLEVEL%" NEQ "0" goto AdbNotFound

set DEVICE=
if not "%1"=="" set DEVICE=-s %1
for /f "delims=" %%A in ('%ADB% %DEVICE% shell "echo $EXTERNAL_STORAGE"') do @set STORAGE=%%A

:: Check to make sure required environment variables are defined.
if "%TEST_NAME%"=="" goto EnvVarNotFound
if "%TEST_CLASS%"=="" goto EnvVarNotFound
if "%TEST_ACTIVITY%"=="" goto EnvVarNotFound
if "%TEST_SECONDS%"=="" set TEST_SECONDS=15

:: Derived variables.
set TEST_AUTODRIVE=%TEST_NAME%.autodriver
set LOGCAT_FILE=%TEST_NAME%.logcat.txt
set LOGCAT_HIGHLIGHTS_FILE=%TEST_NAME%.logcat.highlights.txt

echo.
echo ===== Playing Back: %TEST_AUTODRIVE% in app %TEST_CLASS% =====

:: Copy the autodriver file to the device.
%ADB% %DEVICE% push %TEST_AUTODRIVE% %STORAGE%/Android/data/%TEST_CLASS%/AutoDriver/default.autodriver > nul
if "%ERRORLEVEL%" NEQ "0" goto TestFileCopyError

:: Setup AutoDriver properties and run the app.
%ADB% %DEVICE% shell setprop debug.oculus.vrapilayers AutoDriver
%ADB% %DEVICE% shell setprop debug.oculus.autoDriverApp %TEST_CLASS%
%ADB% %DEVICE% shell setprop debug.oculus.autoDriverMode Playback
%ADB% %DEVICE% shell setprop debug.oculus.autoDriverPlaybackHeadMode HeadLocked
%ADB% %DEVICE% shell am start -S %TEST_CLASS%/%TEST_ACTIVITY%  > nul 2>&1

:: Sleep while we give the test some time to finish.
timeout /t %TEST_SECONDS%

:: Shutdown the app.
%ADB% %DEVICE% shell am force-stop %TEST_CLASS%
goto Finished

:TestFileCopyError
@echo.
@echo Error: [Test Instrumentation] Failed to copy autodriver files to the device. Does '%TEST_AUTODRIVE%' exist?
goto Finished

:AdbNotFound
@echo.
@echo Error: [Test Instrumentation] %ADB% could not be found. Please make sure it's on your PATH.
goto Finished

:EnvVarNotFound
@echo.
@echo Error: The following environment variables must be defined: TEST_NAME, TEST_CLASS,
@echo        The following environment variables are optional: TEST_SECONDS
goto Finished

:Finished
@echo Playback Finished

pause
