:: This script (prototype) helps you record AutoDriver inputs (e.g.) that you can later
:: use in an E2E test.  It handles (1) setting the appropriate AutoDriver properties,
:: (2) launching the target app in record mode and (3) fetching the newly created
:: autodriver file that you can later use in an E2E test.
::
:: Prerequisites:
:: 1) Plug your quest into your computer.
:: 2) Make sure your target App (APK and OBB if applicable) are installed on your Quest
:: device.
:: 3) Make sure 'adb.exe' is on your PATH or set ADB to point to it.
:: 4) Set environment variables:
::    - TEST_NAME: Choose a new name for your test. This name will be used in your output
::                 filenames.
::    - TEST_CLASS: The classname associated with your target app (e.g.,
::                  com.oculus.OculusInputTest)
::    - TEST_ACTIVITY: The main activity of the app (e.g., com.epicgames.ue4.GameActivity)
::    - TEST_SECONDS (optional): This is how long you will have to record your inputs.
::
:: Instructions:
:: 1) Run the script
:: 2) When the script tells you, don your headset and do stuff
:: 3) Use PlaybackAutoDriverInputs.bat to sanity check your autodriver recording
:: 4) Use the test outputs (listed at the end) to create an E2E test.

@echo off
setlocal enabledelayedexpansion

:: Setup system and device variables.
if "%ADB%"=="" set ADB=adb.exe
%ADB% help > nul
if "%ERRORLEVEL%" NEQ "0" goto AdbNotFound

set DEVICE=
if not "%1"=="" set DEVICE=-s %1
for /f "delims=" %%A in ('%ADB% %DEVICE% shell "echo $EXTERNAL_STORAGE"') do @set STORAGE=%%A

:: Check to make sure required environment variables are defined.
if "%TEST_NAME%"=="" goto EnvVarNotFound
if "%TEST_CLASS%"=="" goto EnvVarNotFound
if "%TEST_SECONDS%"=="" set TEST_SECONDS=15

:: Derived variables.
set TEST_AUTODRIVE=%TEST_NAME%.autodriver
set LOGCAT_FILE=%TEST_NAME%.logcat.txt
set LOGCAT_HIGHLIGHTS_FILE=%TEST_NAME%.logcat.highlights.txt

echo.
echo ===== Launching App Activity: %TEST_CLASS% =====

:: Clear the logcat so that we get a smaller result when we fetch it (after the test run)
%ADB% %DEVICE% logcat -c

:: Run the test app in autodrive mode.
%ADB% %DEVICE% shell setprop debug.oculus.vrapilayers AutoDriver
%ADB% %DEVICE% shell setprop debug.oculus.autoDriverApp %TEST_CLASS%
%ADB% %DEVICE% shell setprop debug.oculus.autoDriverMode Record
%ADB% %DEVICE% shell am start -S %TEST_CLASS%/%TEST_ACTIVITY%  > nul 2>&1

echo Put you headset on and do stuff--your user inputs will be recorded

:: Sleep while we give the app to launch and the user to make their inputs
timeout /t %TEST_SECONDS%

:: Shut AutoDriver and the app down.
%ADB% %DEVICE% shell am broadcast -a com.oculus.vrapilayers.AutoDriver.SHUTDOWN
%ADB% %DEVICE% shell am force-stop %TEST_CLASS%

:: Fetch the logs from the test run.
%ADB% %DEVICE% logcat -d > %LOGCAT_FILE%

:: Fetch the newly created autodriver file.
%ADB% %DEVICE% pull %STORAGE%/Android/data/%TEST_CLASS%/AutoDriver/default.autodriver %TEST_AUTODRIVE%  > nul

echo.
echo ===== Outputs: %TEST_NAME% =====

echo Your user inputs were saved here: %TEST_AUTODRIVE%

echo Complete logcat saved here: %LOGCAT_FILE%

::
:: Test exit points
::

:SuccessfulRun
goto Finished

:AdbNotFound
@echo.
@echo Error: %ADB% could not be found. Please make sure it's on your PATH or set $ADB to point to it.
goto Finished

:EnvVarNotFound
@echo.
@echo Error: The following environment variables must be defined: TEST_NAME, TEST_CLASS,
@echo        The following environment variables are optional: TEST_SECONDS
goto Finished

:Finished
pause
